@@ -1,5 +1,6 @@
 #!/bin/sh
 #
+# Copyright (C) 2022-2025 Claes Nästén <pekdon@gmail.com>
 # Copyright (C) 2003-2021 the pekwm development team
 #
 # Add this to your menu to use this script:
@@ -17,8 +18,8 @@ fi
 
 # pekwm configuration directory, setup by pekwm but use this to ensure
 # that the script will run properly without running from pekwm.
-if test -z "$PEKWM_CONFIG_PATH"; then
-    PEKWM_CONFIG_PATH="$HOME/.pekwm"
+if test -z "$PEKWM_CONFIG_FILE"; then
+    PEKWM_CONFIG_FILE="$HOME/.pekwm/config"
 fi
 
 if test -z "${2}"; then
@@ -57,6 +58,11 @@ else
 
     theme=`echo "${2}" | /usr/bin/sed -e "s@^${HOME}@~@" | /usr/bin/sed -e 's@\/@\\\/@g'`
     variant="${3}"
+    # Use auto variant if no variant is specified to follow time of day
+    # changes
+    if test "x${variant}" = "x"; then
+	    variant="auto"
+    fi
 
     # Get temporary file, not all platforms have mktemp though
     if test -x "/bin/mktemp"; then
@@ -74,7 +80,9 @@ else
     text='[Tt][Hh][Ee][Mm][Ee]'
 
     /usr/bin/sed -e "/^\([^#]*\)ThemeVariant/d" \
-     -e "s/^\([^#]*\)$text$wspc=$wspc$qq[^$qq]*$qq/\1Theme\2=\3$qq${theme}$qq@    ThemeVariant = $qq${variant}$qq/" \
+     -e "s/^$text$wspc=$wspc$qq[^$qq]*$qq/Theme\1=\2$qq${theme}$qq/" \
+     -e "s/^\([^#]*[ $tab]\)$text$wspc=$wspc$qq[^$qq]*$qq/\1Theme\2=\3$qq${theme}$qq/" \
+     -e "s/Files {/Files {@    ThemeVariant = $qq${variant}$qq/" \
      "${PEKWM_CONFIG_FILE}" \
      | tr '@' '\n' > "${tmp_file}"
     mv "${tmp_file}" "${PEKWM_CONFIG_FILE}"
